# presets
[![PyPI](https://img.shields.io/pypi/v/presets.svg)](https://pypi.python.org/pypi/presets)
[![CI](https://github.com/bmcfee/presets/actions/workflows/ci.yml/badge.svg)](https://github.com/bmcfee/presets/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/bmcfee/presets/graph/badge.svg?token=MOplTIz54j)](https://codecov.io/gh/bmcfee/presets)
[![License](https://img.shields.io/github/license/bmcfee/presets.svg)]()
[![Documentation Status](https://readthedocs.org/projects/presets/badge/?version=latest)](http://presets.readthedocs.org/en/latest/?badge=latest)

A python module to manipulate default parameters of a module's functions.

For instructions, please refer to the [documentation](http://presets.readthedocs.org/en/latest/).
